# Generated by roxygen2: do not edit by hand

export(agg_seq)
export(calc_sim_cor)
export(calc_sim_seq)
export(calc_sum_stats)
export(combine_sim_seq)
export(combine_sims)
export(compare_sim_meas)
export(compare_style)
export(cor_sim_seq)
export(create_windows)
export(gen_sim_report)
export(heatmap_sim)
export(lex_sim_seq)
export(lexical_sim_dyads)
export(lexical_similarity)
export(norm_sim)
export(participant_sim_dyads)
export(plot_cor_heatmap)
export(plot_sim_comp)
export(plot_sim_cor_heatmap)
export(plot_sim_multi)
export(plot_sim_seq)
export(plot_sim_time)
export(plot_sims)
export(plot_sum_stats)
export(preprocess_dyads)
export(preprocess_text)
export(print_sim_report)
export(radar_sim)
export(run_example)
export(sem_sim_seq)
export(semantic_sim_dyads)
export(semantic_similarity)
export(sent_sim_seq)
export(sentiment_sim_dyads)
export(sentiment_similarity)
export(structural_sim_dyads)
export(structural_similarity)
export(style_sim_seq)
export(stylistic_sim_dyads)
export(stylistic_similarity)
export(timing_sim_dyads)
export(topic_sim_dyads)
export(topic_sim_seq)
export(topic_similarity)
import(ggplot2)
import(lme4)
import(slam)
import(tm)
import(topicmodels)
importFrom(lsa,cosine)
importFrom(lsa,lsa)
importFrom(sentimentr,sentiment_by)
importFrom(stats,cor)
importFrom(stats,sd)
importFrom(tm,Corpus)
importFrom(tm,DocumentTermMatrix)
importFrom(tm,VectorSource)
importFrom(tm,weightTfIdf)
importFrom(topicmodels,LDA)
importFrom(topicmodels,posterior)
importFrom(word2vec,word2vec)
